[pypy-commit] pypy fast-gil: translation fix

arigo noreply at buildbot.pypy.org
Tue Jun 24 15:42:25 CEST 2014


Author: Armin Rigo <arigo at tunes.org>
Branch: fast-gil
Changeset: r72194:bda8c56bee80
Date: 2014-06-24 15:06 +0200
http://bitbucket.org/pypy/pypy/changeset/bda8c56bee80/

Log:	translation fix

diff --git a/rpython/translator/c/gcc/trackgcroot.py b/rpython/translator/c/gcc/trackgcroot.py
--- a/rpython/translator/c/gcc/trackgcroot.py
+++ b/rpython/translator/c/gcc/trackgcroot.py
@@ -858,7 +858,10 @@
         return []
 
     def _visit_xchg(self, line):
-        # only support the format used in VALGRIND_DISCARD_TRANSLATIONS
+        # ignore the 'rpy_fastgil' atomic exchange
+        if 'rpy_fastgil' in line:
+            return []
+        # support the format used in VALGRIND_DISCARD_TRANSLATIONS
         # which is to use a marker no-op "xchgl %ebx, %ebx"
         match = self.r_binaryinsn.match(line)
         source = match.group("source")


More information about the pypy-commit mailing list